==> myanimelist_api-0.2.0.tar.gz: lib/src/models.dart <==
/* 
 * Copyright (C) 2021 Real Phoenix <https://github.com/rsktg>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

export 'models/anime/anime.dart';
export 'models/anime/broadcast.dart';
export 'models/anime/my_list_status.dart';
export 'models/anime/start_season.dart';
export 'models/anime/statistics.dart';
export 'models/anime/status.dart';
export 'models/anime/studio.dart';
export 'models/generic/alternative_titles.dart';
export 'models/generic/generic_response.dart';
export 'models/generic/genre.dart';
export 'models/generic/main_picture.dart';
export 'models/generic/node.dart';
export 'models/generic/node_container.dart';
export 'models/generic/picture.dart';
export 'models/generic/ranked_node.dart';
export 'models/generic/ranked_response.dart';
export 'models/generic/ranking.dart';
export 'models/generic/recommendation.dart';
export 'models/generic/relation.dart';
export 'models/manga/author.dart';
export 'models/manga/author_node.dart';
export 'models/manga/manga.dart';
export 'models/manga/my_list_status.dart';
export 'models/manga/serial_node.dart';
export 'models/manga/serialization.dart';

==> myanimelist_api-0.3.0.tar.gz: lib/src/models.dart <==
/* 
 * Copyright (C) 2021 Real Phoenix <https://github.com/rsktg>
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

export 'models/anime/anime.dart';
export 'models/anime/broadcast.dart';
export 'models/anime/my_list_status.dart';
export 'models/anime/start_season.dart';
export 'models/anime/statistics.dart';
export 'models/anime/status.dart';
export 'models/anime/studio.dart';
export 'models/generic/alternative_titles.dart';
export 'models/generic/genre.dart';
export 'models/generic/main_picture.dart';
export 'models/generic/node.dart';
export 'models/generic/picture.dart';
export 'models/generic/ranked_node.dart';
export 'models/generic/ranking.dart';
export 'models/generic/recommendation.dart';
export 'models/generic/relation.dart';
export 'models/lists/anime_list.dart';
export 'models/lists/manga_list.dart';
export 'models/manga/author.dart';
export 'models/manga/author_node.dart';
export 'models/manga/manga.dart';
export 'models/manga/my_list_status.dart';
export 'models/manga/serial_node.dart';
export 'models/manga/serialization.dart';
export 'models/user/anime_statistics.dart';
export 'models/user/user.dart';
